# voiceos
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 1.0.0
- Generator version: 7.4.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import voiceos
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import voiceos
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import voiceos
from voiceos.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = voiceos.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: APIKeyHeader
configuration.api_key['APIKeyHeader'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['APIKeyHeader'] = 'Bearer'


# Enter a context with an instance of the API client
with voiceos.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = voiceos.AgentsApi(api_client)
    agent_configuration = voiceos.AgentConfiguration() # AgentConfiguration | 

    try:
        # Create Agent
        api_response = api_instance.create_agent(agent_configuration)
        print("The response of AgentsApi->create_agent:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AgentsApi->create_agent: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AgentsApi* | [**create_agent**](docs/AgentsApi.md#create_agent) | **POST** /agents | Create Agent
*AgentsApi* | [**delete_agent**](docs/AgentsApi.md#delete_agent) | **DELETE** /agents/{agent_id} | Delete Agent
*AgentsApi* | [**get_agent**](docs/AgentsApi.md#get_agent) | **GET** /agents/{agent_id} | Get Agent
*AgentsApi* | [**list_agents**](docs/AgentsApi.md#list_agents) | **GET** /agents | List Agents
*AgentsApi* | [**update_agent**](docs/AgentsApi.md#update_agent) | **PATCH** /agents/{agent_id} | Update Agent
*CallsApi* | [**create_call**](docs/CallsApi.md#create_call) | **POST** /calls/create | Create Call
*CallsApi* | [**get_call**](docs/CallsApi.md#get_call) | **GET** /calls/{call_id} | Get Call
*CallsApi* | [**get_recording**](docs/CallsApi.md#get_recording) | **GET** /calls/{call_id}/recording | Get Call Recording
*CallsApi* | [**list_calls**](docs/CallsApi.md#list_calls) | **GET** /calls | List Calls
*PhoneNumbersApi* | [**buy_phone_number_phone_numbers_buy_post**](docs/PhoneNumbersApi.md#buy_phone_number_phone_numbers_buy_post) | **POST** /phone_numbers/buy | Buy Phone Number
*PhoneNumbersApi* | [**delete_phone_number_phone_numbers_phone_number_delete**](docs/PhoneNumbersApi.md#delete_phone_number_phone_numbers_phone_number_delete) | **DELETE** /phone_numbers/{phone_number} | Delete Phone Number
*PhoneNumbersApi* | [**get_phone_number**](docs/PhoneNumbersApi.md#get_phone_number) | **GET** /phone_numbers/{phone_number} | Get Phone Number
*PhoneNumbersApi* | [**list_available_phone_numbers**](docs/PhoneNumbersApi.md#list_available_phone_numbers) | **GET** /phone_numbers/buy | List Available Phone Numbers
*PhoneNumbersApi* | [**list_phone_numbers**](docs/PhoneNumbersApi.md#list_phone_numbers) | **GET** /phone_numbers | List Phone Numbers
*PhoneNumbersApi* | [**update_phone_number_phone_numbers_phone_number_patch**](docs/PhoneNumbersApi.md#update_phone_number_phone_numbers_phone_number_patch) | **PATCH** /phone_numbers/{phone_number} | Update Phone Number


## Documentation For Models

 - [Agent](docs/Agent.md)
 - [AgentConfiguration](docs/AgentConfiguration.md)
 - [AgentCost](docs/AgentCost.md)
 - [AgentLanguage](docs/AgentLanguage.md)
 - [AgentPagination](docs/AgentPagination.md)
 - [AgentProvider](docs/AgentProvider.md)
 - [AgentResponse](docs/AgentResponse.md)
 - [AzureLanguages](docs/AzureLanguages.md)
 - [AzureModel](docs/AzureModel.md)
 - [AzureSynthesizer](docs/AzureSynthesizer.md)
 - [AzureTranscriber](docs/AzureTranscriber.md)
 - [BuyPhoneNumber](docs/BuyPhoneNumber.md)
 - [CallCost](docs/CallCost.md)
 - [CallRecording](docs/CallRecording.md)
 - [CallResponse](docs/CallResponse.md)
 - [CallStatus](docs/CallStatus.md)
 - [CallType](docs/CallType.md)
 - [CallsPagination](docs/CallsPagination.md)
 - [ChatGPT](docs/ChatGPT.md)
 - [CreateCall](docs/CreateCall.md)
 - [Currency](docs/Currency.md)
 - [DeepgramLanguages](docs/DeepgramLanguages.md)
 - [DeepgramModel](docs/DeepgramModel.md)
 - [DeepgramTranscriber](docs/DeepgramTranscriber.md)
 - [ElevenLabsModel](docs/ElevenLabsModel.md)
 - [ElevenLabsSynthesizer](docs/ElevenLabsSynthesizer.md)
 - [EndedReasons](docs/EndedReasons.md)
 - [EventName](docs/EventName.md)
 - [EventVariableName](docs/EventVariableName.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [LanguageModelCost](docs/LanguageModelCost.md)
 - [Message](docs/Message.md)
 - [MessageRole](docs/MessageRole.md)
 - [MethodEnum](docs/MethodEnum.md)
 - [OpenAI](docs/OpenAI.md)
 - [OpenAIFunction](docs/OpenAIFunction.md)
 - [OpenAIFunctionParameter](docs/OpenAIFunctionParameter.md)
 - [OpenAIFunctionType](docs/OpenAIFunctionType.md)
 - [Operator](docs/Operator.md)
 - [PhoneNumber](docs/PhoneNumber.md)
 - [PhoneNumberPagination](docs/PhoneNumberPagination.md)
 - [PhoneNumberResponse](docs/PhoneNumberResponse.md)
 - [PhoneNumberToBuy](docs/PhoneNumberToBuy.md)
 - [RimeSynthesizer](docs/RimeSynthesizer.md)
 - [SynthesizerCost](docs/SynthesizerCost.md)
 - [TelephonyCost](docs/TelephonyCost.md)
 - [Transcriber](docs/Transcriber.md)
 - [Transcriber1](docs/Transcriber1.md)
 - [TranscriberCost](docs/TranscriberCost.md)
 - [TwilioTelephony](docs/TwilioTelephony.md)
 - [UpdateAgent](docs/UpdateAgent.md)
 - [UpdatePhoneNumber](docs/UpdatePhoneNumber.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)
 - [Voice](docs/Voice.md)
 - [Voice1](docs/Voice1.md)
 - [WakoApiModelsLanguageModelProvider](docs/WakoApiModelsLanguageModelProvider.md)
 - [WakoApiModelsPhoneNumberProvider](docs/WakoApiModelsPhoneNumberProvider.md)
 - [WakoApiModelsSynthesizerProvider](docs/WakoApiModelsSynthesizerProvider.md)
 - [WakoApiModelsTranscriberProvider](docs/WakoApiModelsTranscriberProvider.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="APIKeyHeader"></a>
### APIKeyHeader

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author




